#include <DualWheelTruck.h> // Подключение библиотеки <DualWheelTruck.h> для работы с моторами
#include <SmoothServo.h> // Подключение библиотеки <SmoothServo.h> для работы с сервоприводами
#include "IRremote.h" // Подключение библиотеки <IRremote.h> для работы с ИК приемником

#define LEFT_LED 6 // Назначение пина, к которому подключен левый светодиод
#define RIGHT_LED 11 // Назначение пина, к которому подключен правый светодиод
#define FOOT_DOWN 30 // Назначение угла поворота вала сервопривода, при котором ударный механизм опущен
#define FOOT_UP 0 // Назначение угла поворота вала сервопривода, при котором ударный механизм поднят

int res; // Объявление переменной res
int speeds=100; // Б.1 - Объявление переменной speeds и присвоение ей значения 100

void first_hit(); // Объявление функции first_hit()
void second_hit(); // Объявление функции second_hit()

DCMotor* motor_right; // Инициализация мотора и присвоение ему имени motor_right
DCMotor* motor_left; // Инициализация мотора и присвоение ему имени motor_left

SmoothServo* foot; // Инициализация сервопривода и присвоение ему имени foot

IRrecv irrecv(5); // Указание номера пина, к которому подключен ИК приемник
decode_results results;

void setup() {
Board::vertor_PCA(); // Объявление типа используемого контроллера - vertor_PCA

motor_right = new DCMotor(1, 0, true, 5); // Настройка мотора motor_right с применением функции DCMotor(a, b, c, d): подключен к клеммнику 1, прямая полярность подключения мотора, инерционность 5
motor_left = new DCMotor(0, 0, false, 5); // Настройка мотора motor_left с применением функции DCMotor(a, b, c, d): подключен к клеммнику 0, обратная полярность подключения мотора, инерционность 5

motor_right->stop(false); // Команда на остановку вращения мотора motor_right
motor_left->stop(false); // Команда на остановку вращения мотора motor_left

irrecv.enableIRIn(); // Инициализация ИК приемника

foot = new SmoothServo(15); // Указание номера штыря, к которому подключен сервопривод foot
                                        
foot->setMinAngularSpeed(70); // Установка минимальной угловой скорости поворота вала сервопривода foot
foot->setMaxAngularSpeed(180); // Установка максимальной угловой скорости поворота вала сервопривода foot
  
foot->begin(30); // Команда на запуск работы с сервоприводом foot

foot->rotate(FOOT_DOWN); // Б.2 - Команда на плавный поворот вала серводвигателя foot в положение FOOT_DOWN градусов
 
pinMode (LEFT_LED,OUTPUT); // Настройка пина LEFT_LED на вывод
pinMode (RIGHT_LED,OUTPUT); // Настройка пина RIGHT_LED на вывод
}

void loop() {
  if (irrecv.decode(&results)) // Б.3, Б.4 - Если есть данные для обработки от ИК приемника, то выполнить инструкции в скобках
  { 
    res=results.value; // Б.7 - Сохранение значения, возвращаемого функцией results.value в переменную res
    irrecv.resume(); // Команда на возобновления работы ИК приемника     
  }
    else
    {
      motor_right->stop(false); // Б.5 - Команда на остановку вращения мотора motor_right
      motor_left->stop(false); // Б.5 - Команда на остановку вращения мотора motor_left 
      res=0; // Б.6 - Присвоение переменной res значения 0                
    }
   
    if (res==0x629D) // Б.8 - Если значение переменной res равно 0x629D, то начать выполнение инструкций в скобках
    {
      motor_right->forward(speeds); // Б.9 - Команда на запуск мотора motor_right со скоростью speeds % в прямом направлении
      motor_left->forward(speeds); // Б.9 - Команда на запуск мотора motor_left со скоростью speeds % в прямом направлении     
    }
    else if (res==0xA857) // Б.10 - Если значение переменной res равно 0xA857, то начать выполнение инструкций в скобках
    {
      motor_right->backward(speeds); // Б.11 - Команда на запуск мотора motor_right со скоростью speeds % в обратном направлении
      motor_left->backward(speeds); // Б.11 - Команда на запуск мотора motor_left со скоростью speeds % в обратном направлении       
    }
    else if( res==0xC23D) // Б.12 - Если значение переменной res равно 0xC23D, то начать выполнение инструкций в скобках
    {
      motor_right->backward(speeds); // Б.13 - Команда на запуск мотора motor_right со скоростью speeds % в обратном направлении
      motor_left->forward(speeds); // Б.13 - Команда на запуск мотора motor_left со скоростью speeds % в прямом направлении      
    }
    else if(res==0x22DD) // Б.14 - Если значение переменной res равно 0x22DD, то начать выполнение инструкций в скобках
    {
      motor_right->forward(speeds); // Б.15 - Команда на запуск мотора motor_right со скоростью speeds % в прямом направлении
      motor_left->backward(speeds); // Б.15 - Команда на запуск мотора motor_left со скоростью speeds % в обратном направлении          
    }
     else if(res==0x42BD) // Б.16 - Если значение переменной res равно 0x42BD, то начать выполнение инструкций в скобках
    {      
        first_hit(); // Б.17 - Вызов на исполнение функции first_hit()       
    }
    else if(res==0x2FD) // Б.18 - Если значение переменной res равно 0x2FD, то начать выполнение инструкций в скобках
    {      
        second_hit(); // Б.19 - Вызов на исполнение функции second_hit()      
    }    
    delay(150); // Б.20 - Ожидание 0,15 секунды    
}

void first_hit()
{  
  foot->smoothRotate(FOOT_UP); // Б.17.1 - Команда на плавный поворот вала серводвигателя foot в положение FOOT_UP градусов
  digitalWrite(RIGHT_LED,HIGH); // Б.17.2 - Установить на пине RIGHT_LED напряжение, соответствующее уровню "HIGH" 
  delay(1000); // Б.17.3 - Ожидание 1 секунда 
  foot->smoothRotate(FOOT_DOWN); // Б.17.4 - Команда на плавный поворот вала серводвигателя foot в положение FOOT_DOWN градусов
  digitalWrite(RIGHT_LED,LOW); // Б.17.5 - Установить на пине RIGHT_LED напряжение, соответствующее уровню "LOW"   
}

void second_hit()
{
  foot->rotate(FOOT_UP); // Б.19.1 - Команда на плавный поворот вала серводвигателя foot в положение FOOT_UP градусов  
  digitalWrite(LEFT_LED,HIGH); // Б.19.2 - Установить на пине LEFT_LED напряжение, соответствующее уровню "HIGH" 
  delay(500); // Б.19.3 - Ожидание 0,5 секунды 
  foot->rotate(FOOT_DOWN); // Б.19.4 - Команда на плавный поворот вала серводвигателя foot в положение FOOT_DOWN градусов  
  digitalWrite(LEFT_LED,LOW); // Б.19.5 - Установить на пине LEFT_LED напряжение, соответствующее уровню "LOW"   
}
